# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/datacatalog_v1beta1/proto/search.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/datacatalog_v1beta1/proto/search.proto",
    package="google.cloud.datacatalog.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\034com.google.cloud.datacatalogP\001ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\370\001\001"
    ),
    serialized_pb=_b(
        '\n3google/cloud/datacatalog_v1beta1/proto/search.proto\x12 google.cloud.datacatalog.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xbd\x01\n\x13SearchCatalogResult\x12N\n\x12search_result_type\x18\x01 \x01(\x0e\x32\x32.google.cloud.datacatalog.v1beta1.SearchResultType\x12\x1d\n\x15search_result_subtype\x18\x02 \x01(\t\x12\x1e\n\x16relative_resource_name\x18\x03 \x01(\t\x12\x17\n\x0flinked_resource\x18\x04 \x01(\t*d\n\x10SearchResultType\x12"\n\x1eSEARCH_RESULT_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05\x45NTRY\x10\x01\x12\x10\n\x0cTAG_TEMPLATE\x10\x02\x12\x0f\n\x0b\x45NTRY_GROUP\x10\x03\x42p\n\x1c\x63om.google.cloud.datacatalogP\x01ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\xf8\x01\x01\x62\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)

_SEARCHRESULTTYPE = _descriptor.EnumDescriptor(
    name="SearchResultType",
    full_name="google.cloud.datacatalog.v1beta1.SearchResultType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="SEARCH_RESULT_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="ENTRY", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="TAG_TEMPLATE", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="ENTRY_GROUP", index=3, number=3, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=344,
    serialized_end=444,
)
_sym_db.RegisterEnumDescriptor(_SEARCHRESULTTYPE)

SearchResultType = enum_type_wrapper.EnumTypeWrapper(_SEARCHRESULTTYPE)
SEARCH_RESULT_TYPE_UNSPECIFIED = 0
ENTRY = 1
TAG_TEMPLATE = 2
ENTRY_GROUP = 3


_SEARCHCATALOGRESULT = _descriptor.Descriptor(
    name="SearchCatalogResult",
    full_name="google.cloud.datacatalog.v1beta1.SearchCatalogResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="search_result_type",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogResult.search_result_type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="search_result_subtype",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogResult.search_result_subtype",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="relative_resource_name",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogResult.relative_resource_name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="linked_resource",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogResult.linked_resource",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=153,
    serialized_end=342,
)

_SEARCHCATALOGRESULT.fields_by_name["search_result_type"].enum_type = _SEARCHRESULTTYPE
DESCRIPTOR.message_types_by_name["SearchCatalogResult"] = _SEARCHCATALOGRESULT
DESCRIPTOR.enum_types_by_name["SearchResultType"] = _SEARCHRESULTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SearchCatalogResult = _reflection.GeneratedProtocolMessageType(
    "SearchCatalogResult",
    (_message.Message,),
    dict(
        DESCRIPTOR=_SEARCHCATALOGRESULT,
        __module__="google.cloud.datacatalog_v1beta1.proto.search_pb2",
        __doc__="""A result that appears in the response of a search request. Each result
  captures details of one entry that matches the search.
  
  
  Attributes:
      search_result_type:
          Type of the search result. This field can be used to determine
          which Get method to call to fetch the full resource.
      search_result_subtype:
          Sub-type of the search result. This is a dot-delimited
          description of the resource's full type, and is the same as
          the value callers would provide in the "type" search facet.
          Examples: "entry.table", "entry.dataStream", "tagTemplate"
      relative_resource_name:
          The relative resource name of the resource in URL format.
          Examples: "projects/{project\_id}/locations/{location\_id}/ent
          ryGroups/{entry\_group\_id}/entries/{entry\_id}".
          "projects/{project\_id}/tagTemplates/{tag\_template\_id}".
      linked_resource:
          The full name of the cloud resource the entry belongs to. See:
          https://cloud.google.com/apis/design/resource\_names#full\_res
          ource\_name Example: "//bigquery.googleapis.com/projects/proje
          ctId/datasets/datasetId/tables/tableId".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.SearchCatalogResult)
    ),
)
_sym_db.RegisterMessage(SearchCatalogResult)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import

from google.cloud.datacatalog_v1beta1 import types
from google.cloud.datacatalog_v1beta1.gapic import data_catalog_client
from google.cloud.datacatalog_v1beta1.gapic import enums


class DataCatalogClient(data_catalog_client.DataCatalogClient):
    __doc__ = data_catalog_client.DataCatalogClient.__doc__
    enums = enums


__all__ = ("enums", "types", "DataCatalogClient")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/datacatalog_v1beta1/proto/schema.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/datacatalog_v1beta1/proto/schema.proto",
    package="google.cloud.datacatalog.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\034com.google.cloud.datacatalogP\001ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\370\001\001"
    ),
    serialized_pb=_b(
        '\n3google/cloud/datacatalog_v1beta1/proto/schema.proto\x12 google.cloud.datacatalog.v1beta1"I\n\x06Schema\x12?\n\x07\x63olumns\x18\x02 \x03(\x0b\x32..google.cloud.datacatalog.v1beta1.ColumnSchema"\x93\x01\n\x0c\x43olumnSchema\x12\x0e\n\x06\x63olumn\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04mode\x18\x03 \x01(\t\x12\x42\n\nsubcolumns\x18\x07 \x03(\x0b\x32..google.cloud.datacatalog.v1beta1.ColumnSchemaBp\n\x1c\x63om.google.cloud.datacatalogP\x01ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\xf8\x01\x01\x62\x06proto3'
    ),
)


_SCHEMA = _descriptor.Descriptor(
    name="Schema",
    full_name="google.cloud.datacatalog.v1beta1.Schema",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="columns",
            full_name="google.cloud.datacatalog.v1beta1.Schema.columns",
            index=0,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=89,
    serialized_end=162,
)


_COLUMNSCHEMA = _descriptor.Descriptor(
    name="ColumnSchema",
    full_name="google.cloud.datacatalog.v1beta1.ColumnSchema",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="column",
            full_name="google.cloud.datacatalog.v1beta1.ColumnSchema.column",
            index=0,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.datacatalog.v1beta1.ColumnSchema.type",
            index=1,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.datacatalog.v1beta1.ColumnSchema.description",
            index=2,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="mode",
            full_name="google.cloud.datacatalog.v1beta1.ColumnSchema.mode",
            index=3,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="subcolumns",
            full_name="google.cloud.datacatalog.v1beta1.ColumnSchema.subcolumns",
            index=4,
            number=7,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=165,
    serialized_end=312,
)

_SCHEMA.fields_by_name["columns"].message_type = _COLUMNSCHEMA
_COLUMNSCHEMA.fields_by_name["subcolumns"].message_type = _COLUMNSCHEMA
DESCRIPTOR.message_types_by_name["Schema"] = _SCHEMA
DESCRIPTOR.message_types_by_name["ColumnSchema"] = _COLUMNSCHEMA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Schema = _reflection.GeneratedProtocolMessageType(
    "Schema",
    (_message.Message,),
    dict(
        DESCRIPTOR=_SCHEMA,
        __module__="google.cloud.datacatalog_v1beta1.proto.schema_pb2",
        __doc__="""Represents a schema (e.g. BigQuery, GoogleSQL, Avro schema).
  
  
  Attributes:
      columns:
          Required. Schema of columns. A maximum of 10,000 columns and
          sub-columns can be specified.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.Schema)
    ),
)
_sym_db.RegisterMessage(Schema)

ColumnSchema = _reflection.GeneratedProtocolMessageType(
    "ColumnSchema",
    (_message.Message,),
    dict(
        DESCRIPTOR=_COLUMNSCHEMA,
        __module__="google.cloud.datacatalog_v1beta1.proto.schema_pb2",
        __doc__="""Representation of a column within a schema. Columns could be nested
  inside other columns.
  
  
  Attributes:
      column:
          Required. Name of the column.
      type:
          Required. Type of the column.
      description:
          Optional. Description of the column. Default value is an empty
          string.
      mode:
          Optional. A column's mode indicates whether the values in this
          column are required, nullable, etc. Only 'NULLABLE',
          'REQUIRED' and 'REPEATED' are supported. Default mode is
          'NULLABLE'.
      subcolumns:
          Optional. Schema of sub-columns. A column can have zero or
          more sub-columns.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ColumnSchema)
    ),
)
_sym_db.RegisterMessage(ColumnSchema)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/datacatalog_v1beta1/proto/datacatalog.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.datacatalog_v1beta1.proto import (
    schema_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_schema__pb2,
)
from google.cloud.datacatalog_v1beta1.proto import (
    search_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_search__pb2,
)
from google.cloud.datacatalog_v1beta1.proto import (
    table_spec_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_table__spec__pb2,
)
from google.cloud.datacatalog_v1beta1.proto import (
    tags_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2,
)
from google.cloud.datacatalog_v1beta1.proto import (
    timestamps_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_timestamps__pb2,
)
from google.iam.v1 import iam_policy_pb2 as google_dot_iam_dot_v1_dot_iam__policy__pb2
from google.iam.v1 import policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/datacatalog_v1beta1/proto/datacatalog.proto",
    package="google.cloud.datacatalog.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\034com.google.cloud.datacatalogP\001ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\370\001\001"
    ),
    serialized_pb=_b(
        '\n8google/cloud/datacatalog_v1beta1/proto/datacatalog.proto\x12 google.cloud.datacatalog.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x33google/cloud/datacatalog_v1beta1/proto/schema.proto\x1a\x33google/cloud/datacatalog_v1beta1/proto/search.proto\x1a\x37google/cloud/datacatalog_v1beta1/proto/table_spec.proto\x1a\x31google/cloud/datacatalog_v1beta1/proto/tags.proto\x1a\x37google/cloud/datacatalog_v1beta1/proto/timestamps.proto\x1a\x1egoogle/iam/v1/iam_policy.proto\x1a\x1agoogle/iam/v1/policy.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x17google/api/client.proto"\x8f\x02\n\x14SearchCatalogRequest\x12K\n\x05scope\x18\x06 \x01(\x0b\x32<.google.cloud.datacatalog.v1beta1.SearchCatalogRequest.Scope\x12\r\n\x05query\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a\x62\n\x05Scope\x12\x17\n\x0finclude_org_ids\x18\x02 \x03(\t\x12\x1b\n\x13include_project_ids\x18\x03 \x03(\t\x12#\n\x1binclude_gcp_public_datasets\x18\x07 \x01(\x08"x\n\x15SearchCatalogResponse\x12\x46\n\x07results\x18\x01 \x03(\x0b\x32\x35.google.cloud.datacatalog.v1beta1.SearchCatalogResult\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t"}\n\x12UpdateEntryRequest\x12\x36\n\x05\x65ntry\x18\x01 \x01(\x0b\x32\'.google.cloud.datacatalog.v1beta1.Entry\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"\x1f\n\x0fGetEntryRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"V\n\x12LookupEntryRequest\x12\x19\n\x0flinked_resource\x18\x01 \x01(\tH\x00\x12\x16\n\x0csql_resource\x18\x03 \x01(\tH\x00\x42\r\n\x0btarget_name"\xe6\x03\n\x05\x45ntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0flinked_resource\x18\t \x01(\t\x12\x39\n\x04type\x18\x02 \x01(\x0e\x32+.google.cloud.datacatalog.v1beta1.EntryType\x12R\n\x13\x62igquery_table_spec\x18\x0c \x01(\x0b\x32\x33.google.cloud.datacatalog.v1beta1.BigQueryTableSpecH\x00\x12_\n\x1a\x62igquery_date_sharded_spec\x18\x0f \x01(\x0b\x32\x39.google.cloud.datacatalog.v1beta1.BigQueryDateShardedSpecH\x00\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x38\n\x06schema\x18\x05 \x01(\x0b\x32(.google.cloud.datacatalog.v1beta1.Schema\x12T\n\x18source_system_timestamps\x18\x07 \x01(\x0b\x32\x32.google.cloud.datacatalog.v1beta1.SystemTimestampsB\x0b\n\ttype_spec"\x88\x01\n\x18\x43reateTagTemplateRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x17\n\x0ftag_template_id\x18\x03 \x01(\t\x12\x43\n\x0ctag_template\x18\x02 \x01(\x0b\x32-.google.cloud.datacatalog.v1beta1.TagTemplate"%\n\x15GetTagTemplateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"\x90\x01\n\x18UpdateTagTemplateRequest\x12\x43\n\x0ctag_template\x18\x01 \x01(\x0b\x32-.google.cloud.datacatalog.v1beta1.TagTemplate\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"7\n\x18\x44\x65leteTagTemplateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x66orce\x18\x02 \x01(\x08"V\n\x10\x43reateTagRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x32\n\x03tag\x18\x02 \x01(\x0b\x32%.google.cloud.datacatalog.v1beta1.Tag"w\n\x10UpdateTagRequest\x12\x32\n\x03tag\x18\x01 \x01(\x0b\x32%.google.cloud.datacatalog.v1beta1.Tag\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask" \n\x10\x44\x65leteTagRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"\x9e\x01\n\x1d\x43reateTagTemplateFieldRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x1d\n\x15tag_template_field_id\x18\x02 \x01(\t\x12N\n\x12tag_template_field\x18\x03 \x01(\x0b\x32\x32.google.cloud.datacatalog.v1beta1.TagTemplateField"\xae\x01\n\x1dUpdateTagTemplateFieldRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12N\n\x12tag_template_field\x18\x02 \x01(\x0b\x32\x32.google.cloud.datacatalog.v1beta1.TagTemplateField\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"P\n\x1dRenameTagTemplateFieldRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12!\n\x19new_tag_template_field_id\x18\x02 \x01(\t"<\n\x1d\x44\x65leteTagTemplateFieldRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x66orce\x18\x02 \x01(\x08"H\n\x0fListTagsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"`\n\x10ListTagsResponse\x12\x33\n\x04tags\x18\x01 \x03(\x0b\x32%.google.cloud.datacatalog.v1beta1.Tag\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*C\n\tEntryType\x12\x1a\n\x16\x45NTRY_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05TABLE\x10\x02\x12\x0f\n\x0b\x44\x41TA_STREAM\x10\x03\x32\xf8\x1c\n\x0b\x44\x61taCatalog\x12\xa4\x01\n\rSearchCatalog\x12\x36.google.cloud.datacatalog.v1beta1.SearchCatalogRequest\x1a\x37.google.cloud.datacatalog.v1beta1.SearchCatalogResponse""\x82\xd3\xe4\x93\x02\x1c"\x17/v1beta1/catalog:search:\x01*\x12\xc1\x01\n\x0bUpdateEntry\x12\x34.google.cloud.datacatalog.v1beta1.UpdateEntryRequest\x1a\'.google.cloud.datacatalog.v1beta1.Entry"S\x82\xd3\xe4\x93\x02M2D/v1beta1/{entry.name=projects/*/locations/*/entryGroups/*/entries/*}:\x05\x65ntry\x12\xae\x01\n\x08GetEntry\x12\x31.google.cloud.datacatalog.v1beta1.GetEntryRequest\x1a\'.google.cloud.datacatalog.v1beta1.Entry"F\x82\xd3\xe4\x93\x02@\x12>/v1beta1/{name=projects/*/locations/*/entryGroups/*/entries/*}\x12\x8d\x01\n\x0bLookupEntry\x12\x34.google.cloud.datacatalog.v1beta1.LookupEntryRequest\x1a\'.google.cloud.datacatalog.v1beta1.Entry"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1beta1/entries:lookup\x12\xcb\x01\n\x11\x43reateTagTemplate\x12:.google.cloud.datacatalog.v1beta1.CreateTagTemplateRequest\x1a-.google.cloud.datacatalog.v1beta1.TagTemplate"K\x82\xd3\xe4\x93\x02\x45"5/v1beta1/{parent=projects/*/locations/*}/tagTemplates:\x0ctag_template\x12\xb7\x01\n\x0eGetTagTemplate\x12\x37.google.cloud.datacatalog.v1beta1.GetTagTemplateRequest\x1a-.google.cloud.datacatalog.v1beta1.TagTemplate"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v1beta1/{name=projects/*/locations/*/tagTemplates/*}\x12\xd8\x01\n\x11UpdateTagTemplate\x12:.google.cloud.datacatalog.v1beta1.UpdateTagTemplateRequest\x1a-.google.cloud.datacatalog.v1beta1.TagTemplate"X\x82\xd3\xe4\x93\x02R2B/v1beta1/{tag_template.name=projects/*/locations/*/tagTemplates/*}:\x0ctag_template\x12\xa6\x01\n\x11\x44\x65leteTagTemplate\x12:.google.cloud.datacatalog.v1beta1.DeleteTagTemplateRequest\x1a\x16.google.protobuf.Empty"=\x82\xd3\xe4\x93\x02\x37*5/v1beta1/{name=projects/*/locations/*/tagTemplates/*}\x12\xe9\x01\n\x16\x43reateTagTemplateField\x12?.google.cloud.datacatalog.v1beta1.CreateTagTemplateFieldRequest\x1a\x32.google.cloud.datacatalog.v1beta1.TagTemplateField"Z\x82\xd3\xe4\x93\x02T">/v1beta1/{parent=projects/*/locations/*/tagTemplates/*}/fields:\x12tag_template_field\x12\xe9\x01\n\x16UpdateTagTemplateField\x12?.google.cloud.datacatalog.v1beta1.UpdateTagTemplateFieldRequest\x1a\x32.google.cloud.datacatalog.v1beta1.TagTemplateField"Z\x82\xd3\xe4\x93\x02T2>/v1beta1/{name=projects/*/locations/*/tagTemplates/*/fields/*}:\x12tag_template_field\x12\xdf\x01\n\x16RenameTagTemplateField\x12?.google.cloud.datacatalog.v1beta1.RenameTagTemplateFieldRequest\x1a\x32.google.cloud.datacatalog.v1beta1.TagTemplateField"P\x82\xd3\xe4\x93\x02J"E/v1beta1/{name=projects/*/locations/*/tagTemplates/*/fields/*}:rename:\x01*\x12\xb9\x01\n\x16\x44\x65leteTagTemplateField\x12?.google.cloud.datacatalog.v1beta1.DeleteTagTemplateFieldRequest\x1a\x16.google.protobuf.Empty"F\x82\xd3\xe4\x93\x02@*>/v1beta1/{name=projects/*/locations/*/tagTemplates/*/fields/*}\x12\xba\x01\n\tCreateTag\x12\x32.google.cloud.datacatalog.v1beta1.CreateTagRequest\x1a%.google.cloud.datacatalog.v1beta1.Tag"R\x82\xd3\xe4\x93\x02L"E/v1beta1/{parent=projects/*/locations/*/entryGroups/*/entries/*}/tags:\x03tag\x12\xbe\x01\n\tUpdateTag\x12\x32.google.cloud.datacatalog.v1beta1.UpdateTagRequest\x1a%.google.cloud.datacatalog.v1beta1.Tag"V\x82\xd3\xe4\x93\x02P2I/v1beta1/{tag.name=projects/*/locations/*/entryGroups/*/entries/*/tags/*}:\x03tag\x12\xa6\x01\n\tDeleteTag\x12\x32.google.cloud.datacatalog.v1beta1.DeleteTagRequest\x1a\x16.google.protobuf.Empty"M\x82\xd3\xe4\x93\x02G*E/v1beta1/{name=projects/*/locations/*/entryGroups/*/entries/*/tags/*}\x12\xc0\x01\n\x08ListTags\x12\x31.google.cloud.datacatalog.v1beta1.ListTagsRequest\x1a\x32.google.cloud.datacatalog.v1beta1.ListTagsResponse"M\x82\xd3\xe4\x93\x02G\x12\x45/v1beta1/{parent=projects/*/locations/*/entryGroups/*/entries/*}/tags\x12\x9c\x01\n\x0cSetIamPolicy\x12".google.iam.v1.SetIamPolicyRequest\x1a\x15.google.iam.v1.Policy"Q\x82\xd3\xe4\x93\x02K"F/v1beta1/{resource=projects/*/locations/*/tagTemplates/*}:setIamPolicy:\x01*\x12\x9c\x01\n\x0cGetIamPolicy\x12".google.iam.v1.GetIamPolicyRequest\x1a\x15.google.iam.v1.Policy"Q\x82\xd3\xe4\x93\x02K"F/v1beta1/{resource=projects/*/locations/*/tagTemplates/*}:getIamPolicy:\x01*\x12\xc2\x01\n\x12TestIamPermissions\x12(.google.iam.v1.TestIamPermissionsRequest\x1a).google.iam.v1.TestIamPermissionsResponse"W\x82\xd3\xe4\x93\x02Q"L/v1beta1/{resource=projects/*/locations/*/tagTemplates/*}:testIamPermissions:\x01*\x1aN\xca\x41\x1a\x64\x61tacatalog.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformBp\n\x1c\x63om.google.cloud.datacatalogP\x01ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\xf8\x01\x01\x62\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_schema__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_search__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_table__spec__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_timestamps__pb2.DESCRIPTOR,
        google_dot_iam_dot_v1_dot_iam__policy__pb2.DESCRIPTOR,
        google_dot_iam_dot_v1_dot_policy__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
    ],
)

_ENTRYTYPE = _descriptor.EnumDescriptor(
    name="EntryType",
    full_name="google.cloud.datacatalog.v1beta1.EntryType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="ENTRY_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="TABLE", index=1, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="DATA_STREAM", index=2, number=3, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2955,
    serialized_end=3022,
)
_sym_db.RegisterEnumDescriptor(_ENTRYTYPE)

EntryType = enum_type_wrapper.EnumTypeWrapper(_ENTRYTYPE)
ENTRY_TYPE_UNSPECIFIED = 0
TABLE = 2
DATA_STREAM = 3


_SEARCHCATALOGREQUEST_SCOPE = _descriptor.Descriptor(
    name="Scope",
    full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.Scope",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="include_org_ids",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.Scope.include_org_ids",
            index=0,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="include_project_ids",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.Scope.include_project_ids",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="include_gcp_public_datasets",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.Scope.include_gcp_public_datasets",
            index=2,
            number=7,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=717,
    serialized_end=815,
)

_SEARCHCATALOGREQUEST = _descriptor.Descriptor(
    name="SearchCatalogRequest",
    full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="scope",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.scope",
            index=0,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="query",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.query",
            index=1,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.page_size",
            index=2,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.page_token",
            index=3,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="order_by",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.order_by",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_SEARCHCATALOGREQUEST_SCOPE],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=544,
    serialized_end=815,
)


_SEARCHCATALOGRESPONSE = _descriptor.Descriptor(
    name="SearchCatalogResponse",
    full_name="google.cloud.datacatalog.v1beta1.SearchCatalogResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="results",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogResponse.results",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogResponse.next_page_token",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=817,
    serialized_end=937,
)


_UPDATEENTRYREQUEST = _descriptor.Descriptor(
    name="UpdateEntryRequest",
    full_name="google.cloud.datacatalog.v1beta1.UpdateEntryRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="entry",
            full_name="google.cloud.datacatalog.v1beta1.UpdateEntryRequest.entry",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.datacatalog.v1beta1.UpdateEntryRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=939,
    serialized_end=1064,
)


_GETENTRYREQUEST = _descriptor.Descriptor(
    name="GetEntryRequest",
    full_name="google.cloud.datacatalog.v1beta1.GetEntryRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.GetEntryRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1066,
    serialized_end=1097,
)


_LOOKUPENTRYREQUEST = _descriptor.Descriptor(
    name="LookupEntryRequest",
    full_name="google.cloud.datacatalog.v1beta1.LookupEntryRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="linked_resource",
            full_name="google.cloud.datacatalog.v1beta1.LookupEntryRequest.linked_resource",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="sql_resource",
            full_name="google.cloud.datacatalog.v1beta1.LookupEntryRequest.sql_resource",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="target_name",
            full_name="google.cloud.datacatalog.v1beta1.LookupEntryRequest.target_name",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1099,
    serialized_end=1185,
)


_ENTRY = _descriptor.Descriptor(
    name="Entry",
    full_name="google.cloud.datacatalog.v1beta1.Entry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.Entry.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="linked_resource",
            full_name="google.cloud.datacatalog.v1beta1.Entry.linked_resource",
            index=1,
            number=9,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.datacatalog.v1beta1.Entry.type",
            index=2,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="bigquery_table_spec",
            full_name="google.cloud.datacatalog.v1beta1.Entry.bigquery_table_spec",
            index=3,
            number=12,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="bigquery_date_sharded_spec",
            full_name="google.cloud.datacatalog.v1beta1.Entry.bigquery_date_sharded_spec",
            index=4,
            number=15,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.datacatalog.v1beta1.Entry.display_name",
            index=5,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.datacatalog.v1beta1.Entry.description",
            index=6,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="schema",
            full_name="google.cloud.datacatalog.v1beta1.Entry.schema",
            index=7,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="source_system_timestamps",
            full_name="google.cloud.datacatalog.v1beta1.Entry.source_system_timestamps",
            index=8,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="type_spec",
            full_name="google.cloud.datacatalog.v1beta1.Entry.type_spec",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1188,
    serialized_end=1674,
)


_CREATETAGTEMPLATEREQUEST = _descriptor.Descriptor(
    name="CreateTagTemplateRequest",
    full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tag_template_id",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateRequest.tag_template_id",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tag_template",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateRequest.tag_template",
            index=2,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1677,
    serialized_end=1813,
)


_GETTAGTEMPLATEREQUEST = _descriptor.Descriptor(
    name="GetTagTemplateRequest",
    full_name="google.cloud.datacatalog.v1beta1.GetTagTemplateRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.GetTagTemplateRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1815,
    serialized_end=1852,
)


_UPDATETAGTEMPLATEREQUEST = _descriptor.Descriptor(
    name="UpdateTagTemplateRequest",
    full_name="google.cloud.datacatalog.v1beta1.UpdateTagTemplateRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="tag_template",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTagTemplateRequest.tag_template",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTagTemplateRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1855,
    serialized_end=1999,
)


_DELETETAGTEMPLATEREQUEST = _descriptor.Descriptor(
    name="DeleteTagTemplateRequest",
    full_name="google.cloud.datacatalog.v1beta1.DeleteTagTemplateRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.DeleteTagTemplateRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="force",
            full_name="google.cloud.datacatalog.v1beta1.DeleteTagTemplateRequest.force",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2001,
    serialized_end=2056,
)


_CREATETAGREQUEST = _descriptor.Descriptor(
    name="CreateTagRequest",
    full_name="google.cloud.datacatalog.v1beta1.CreateTagRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tag",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagRequest.tag",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2058,
    serialized_end=2144,
)


_UPDATETAGREQUEST = _descriptor.Descriptor(
    name="UpdateTagRequest",
    full_name="google.cloud.datacatalog.v1beta1.UpdateTagRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="tag",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTagRequest.tag",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTagRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2146,
    serialized_end=2265,
)


_DELETETAGREQUEST = _descriptor.Descriptor(
    name="DeleteTagRequest",
    full_name="google.cloud.datacatalog.v1beta1.DeleteTagRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.DeleteTagRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2267,
    serialized_end=2299,
)


_CREATETAGTEMPLATEFIELDREQUEST = _descriptor.Descriptor(
    name="CreateTagTemplateFieldRequest",
    full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateFieldRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateFieldRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tag_template_field_id",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateFieldRequest.tag_template_field_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tag_template_field",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateFieldRequest.tag_template_field",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2302,
    serialized_end=2460,
)


_UPDATETAGTEMPLATEFIELDREQUEST = _descriptor.Descriptor(
    name="UpdateTagTemplateFieldRequest",
    full_name="google.cloud.datacatalog.v1beta1.UpdateTagTemplateFieldRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTagTemplateFieldRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tag_template_field",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTagTemplateFieldRequest.tag_template_field",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTagTemplateFieldRequest.update_mask",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2463,
    serialized_end=2637,
)


_RENAMETAGTEMPLATEFIELDREQUEST = _descriptor.Descriptor(
    name="RenameTagTemplateFieldRequest",
    full_name="google.cloud.datacatalog.v1beta1.RenameTagTemplateFieldRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.RenameTagTemplateFieldRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="new_tag_template_field_id",
            full_name="google.cloud.datacatalog.v1beta1.RenameTagTemplateFieldRequest.new_tag_template_field_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2639,
    serialized_end=2719,
)


_DELETETAGTEMPLATEFIELDREQUEST = _descriptor.Descriptor(
    name="DeleteTagTemplateFieldRequest",
    full_name="google.cloud.datacatalog.v1beta1.DeleteTagTemplateFieldRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.DeleteTagTemplateFieldRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="force",
            full_name="google.cloud.datacatalog.v1beta1.DeleteTagTemplateFieldRequest.force",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2721,
    serialized_end=2781,
)


_LISTTAGSREQUEST = _descriptor.Descriptor(
    name="ListTagsRequest",
    full_name="google.cloud.datacatalog.v1beta1.ListTagsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.ListTagsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.datacatalog.v1beta1.ListTagsRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListTagsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2783,
    serialized_end=2855,
)


_LISTTAGSRESPONSE = _descriptor.Descriptor(
    name="ListTagsResponse",
    full_name="google.cloud.datacatalog.v1beta1.ListTagsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="tags",
            full_name="google.cloud.datacatalog.v1beta1.ListTagsResponse.tags",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListTagsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2857,
    serialized_end=2953,
)

_SEARCHCATALOGREQUEST_SCOPE.containing_type = _SEARCHCATALOGREQUEST
_SEARCHCATALOGREQUEST.fields_by_name["scope"].message_type = _SEARCHCATALOGREQUEST_SCOPE
_SEARCHCATALOGRESPONSE.fields_by_name[
    "results"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_search__pb2._SEARCHCATALOGRESULT
)
_UPDATEENTRYREQUEST.fields_by_name["entry"].message_type = _ENTRY
_UPDATEENTRYREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LOOKUPENTRYREQUEST.oneofs_by_name["target_name"].fields.append(
    _LOOKUPENTRYREQUEST.fields_by_name["linked_resource"]
)
_LOOKUPENTRYREQUEST.fields_by_name[
    "linked_resource"
].containing_oneof = _LOOKUPENTRYREQUEST.oneofs_by_name["target_name"]
_LOOKUPENTRYREQUEST.oneofs_by_name["target_name"].fields.append(
    _LOOKUPENTRYREQUEST.fields_by_name["sql_resource"]
)
_LOOKUPENTRYREQUEST.fields_by_name[
    "sql_resource"
].containing_oneof = _LOOKUPENTRYREQUEST.oneofs_by_name["target_name"]
_ENTRY.fields_by_name["type"].enum_type = _ENTRYTYPE
_ENTRY.fields_by_name[
    "bigquery_table_spec"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_table__spec__pb2._BIGQUERYTABLESPEC
)
_ENTRY.fields_by_name[
    "bigquery_date_sharded_spec"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_table__spec__pb2._BIGQUERYDATESHARDEDSPEC
)
_ENTRY.fields_by_name[
    "schema"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_schema__pb2._SCHEMA
)
_ENTRY.fields_by_name[
    "source_system_timestamps"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_timestamps__pb2._SYSTEMTIMESTAMPS
)
_ENTRY.oneofs_by_name["type_spec"].fields.append(
    _ENTRY.fields_by_name["bigquery_table_spec"]
)
_ENTRY.fields_by_name["bigquery_table_spec"].containing_oneof = _ENTRY.oneofs_by_name[
    "type_spec"
]
_ENTRY.oneofs_by_name["type_spec"].fields.append(
    _ENTRY.fields_by_name["bigquery_date_sharded_spec"]
)
_ENTRY.fields_by_name[
    "bigquery_date_sharded_spec"
].containing_oneof = _ENTRY.oneofs_by_name["type_spec"]
_CREATETAGTEMPLATEREQUEST.fields_by_name[
    "tag_template"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATE
)
_UPDATETAGTEMPLATEREQUEST.fields_by_name[
    "tag_template"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATE
)
_UPDATETAGTEMPLATEREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CREATETAGREQUEST.fields_by_name[
    "tag"
].message_type = google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAG
_UPDATETAGREQUEST.fields_by_name[
    "tag"
].message_type = google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAG
_UPDATETAGREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CREATETAGTEMPLATEFIELDREQUEST.fields_by_name[
    "tag_template_field"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATEFIELD
)
_UPDATETAGTEMPLATEFIELDREQUEST.fields_by_name[
    "tag_template_field"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATEFIELD
)
_UPDATETAGTEMPLATEFIELDREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTTAGSRESPONSE.fields_by_name[
    "tags"
].message_type = google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAG
DESCRIPTOR.message_types_by_name["SearchCatalogRequest"] = _SEARCHCATALOGREQUEST
DESCRIPTOR.message_types_by_name["SearchCatalogResponse"] = _SEARCHCATALOGRESPONSE
DESCRIPTOR.message_types_by_name["UpdateEntryRequest"] = _UPDATEENTRYREQUEST
DESCRIPTOR.message_types_by_name["GetEntryRequest"] = _GETENTRYREQUEST
DESCRIPTOR.message_types_by_name["LookupEntryRequest"] = _LOOKUPENTRYREQUEST
DESCRIPTOR.message_types_by_name["Entry"] = _ENTRY
DESCRIPTOR.message_types_by_name["CreateTagTemplateRequest"] = _CREATETAGTEMPLATEREQUEST
DESCRIPTOR.message_types_by_name["GetTagTemplateRequest"] = _GETTAGTEMPLATEREQUEST
DESCRIPTOR.message_types_by_name["UpdateTagTemplateRequest"] = _UPDATETAGTEMPLATEREQUEST
DESCRIPTOR.message_types_by_name["DeleteTagTemplateRequest"] = _DELETETAGTEMPLATEREQUEST
DESCRIPTOR.message_types_by_name["CreateTagRequest"] = _CREATETAGREQUEST
DESCRIPTOR.message_types_by_name["UpdateTagRequest"] = _UPDATETAGREQUEST
DESCRIPTOR.message_types_by_name["DeleteTagRequest"] = _DELETETAGREQUEST
DESCRIPTOR.message_types_by_name[
    "CreateTagTemplateFieldRequest"
] = _CREATETAGTEMPLATEFIELDREQUEST
DESCRIPTOR.message_types_by_name[
    "UpdateTagTemplateFieldRequest"
] = _UPDATETAGTEMPLATEFIELDREQUEST
DESCRIPTOR.message_types_by_name[
    "RenameTagTemplateFieldRequest"
] = _RENAMETAGTEMPLATEFIELDREQUEST
DESCRIPTOR.message_types_by_name[
    "DeleteTagTemplateFieldRequest"
] = _DELETETAGTEMPLATEFIELDREQUEST
DESCRIPTOR.message_types_by_name["ListTagsRequest"] = _LISTTAGSREQUEST
DESCRIPTOR.message_types_by_name["ListTagsResponse"] = _LISTTAGSRESPONSE
DESCRIPTOR.enum_types_by_name["EntryType"] = _ENTRYTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SearchCatalogRequest = _reflection.GeneratedProtocolMessageType(
    "SearchCatalogRequest",
    (_message.Message,),
    dict(
        Scope=_reflection.GeneratedProtocolMessageType(
            "Scope",
            (_message.Message,),
            dict(
                DESCRIPTOR=_SEARCHCATALOGREQUEST_SCOPE,
                __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
                __doc__="""
    Attributes:
        include_org_ids:
            Data Catalog tries to automatically choose the right corpus of
            data to search through. You can ensure an organization is
            included by adding it to "include\_org\_ids". You can ensure a
            project's org is included with "include\_project\_ids". You
            must specify at least one organization using
            "include\_org\_ids" or "include\_project\_ids" in all search
            requests.  List of organization IDs to search within. To find
            your organization ID, follow instructions in
            https://cloud.google.com/resource-manager/docs/creating-
            managing-organization
        include_project_ids:
            List of project IDs to search within. To learn more about the
            distinction between project names/IDs/numbers, go to
            https://cloud.google.com/docs/overview/#projects
        include_gcp_public_datasets:
            If true, include Google Cloud Platform (GCP) public datasets
            in the search results. Info on GCP public datasets is
            available at https://cloud.google.com/public-datasets/. By
            default, GCP public datasets are excluded.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.SearchCatalogRequest.Scope)
            ),
        ),
        DESCRIPTOR=_SEARCHCATALOGREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [SearchCatalog][google.cloud.datacatalog.v1beta1.DataCatalog.SearchCatalog].
  
  
  Attributes:
      scope:
          Required. The scope of this search request.
      query:
          Required. The query string in search query syntax. The query
          must be non-empty.  Query strings can be simple as "x" or more
          qualified as:  -  name:x -  column:x -  description:y  Note:
          Query tokens need to have a minimum of 3 characters for
          substring matching to work correctly. See `Data Catalog Search
          Syntax </data-catalog/docs/how-to/search-reference>`__ for
          more information.
      page_size:
          Number of results in the search page. If <=0 then defaults to
          10. Max limit for page\_size is 1000. Throws an invalid
          argument for page\_size > 1000.
      page_token:
          Optional pagination token returned in an earlier [SearchCatalo
          gResponse.next\_page\_token][google.cloud.datacatalog.v1beta1.
          DataCatalog.SearchCatalogResponse.next\_page\_token];
          indicates that this is a continuation of a prior [SearchCatalo
          g][google.cloud.datacatalog.v1beta1.DataCatalog.SearchCatalog]
          call, and that the system should return the next page of data.
          If empty then the first page is returned.
      order_by:
          Specifies the ordering of results, currently supported case-
          sensitive choices are:  .. raw:: html     <ul>  .. raw:: html
          <li>  relevance  .. raw:: html     </li>  .. raw:: html
          <li>  last\_access\_timestamp [asc\|desc], defaults to
          descending if not specified,  .. raw:: html     </li>  ..
          raw:: html     <li>  last\_modified\_timestamp [asc\|desc],
          defaults to descending if not specified.  .. raw:: html
          </li>  .. raw:: html     </ul>
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.SearchCatalogRequest)
    ),
)
_sym_db.RegisterMessage(SearchCatalogRequest)
_sym_db.RegisterMessage(SearchCatalogRequest.Scope)

SearchCatalogResponse = _reflection.GeneratedProtocolMessageType(
    "SearchCatalogResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_SEARCHCATALOGRESPONSE,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Response message for
  [SearchCatalog][google.cloud.datacatalog.v1beta1.DataCatalog.SearchCatalog].
  
  
  Attributes:
      results:
          Search results in descending order of relevance.
      next_page_token:
          The token that can be used to retrieve the next page of
          results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.SearchCatalogResponse)
    ),
)
_sym_db.RegisterMessage(SearchCatalogResponse)

UpdateEntryRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateEntryRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATEENTRYREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [UpdateEntry][google.cloud.datacatalog.v1beta1.DataCatalog.UpdateEntry].
  
  
  Attributes:
      entry:
          Required. The updated Entry.
      update_mask:
          Optional. The fields to update on the entry. If absent or
          empty, all modifiable fields are updated.  Modifiable fields
          in synced entries:  1. schema (Pub/Sub topics only)
          Modifiable fields in native entries:  1. display\_name 2.
          description 3. schema
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.UpdateEntryRequest)
    ),
)
_sym_db.RegisterMessage(UpdateEntryRequest)

GetEntryRequest = _reflection.GeneratedProtocolMessageType(
    "GetEntryRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETENTRYREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [GetEntry][google.cloud.datacatalog.v1beta1.DataCatalog.GetEntry].
  
  
  Attributes:
      name:
          Required. The name of the entry. For example, "projects/{proje
          ct\_id}/locations/{location}/entryGroups/{entry\_group\_id}/en
          tries/{entry\_id}".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.GetEntryRequest)
    ),
)
_sym_db.RegisterMessage(GetEntryRequest)

LookupEntryRequest = _reflection.GeneratedProtocolMessageType(
    "LookupEntryRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LOOKUPENTRYREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [LookupEntry][google.cloud.datacatalog.v1beta1.DataCatalog.LookupEntry].
  
  
  Attributes:
      target_name:
          Required. Represents either the Google Cloud Platform resource
          or SQL name for a Google Cloud Platform resource.
      linked_resource:
          The full name of the Google Cloud Platform resource the Data
          Catalog entry represents. See: https://cloud.google.com/apis/d
          esign/resource\_names#full\_resource\_name Full names are
          case-sensitive.  Examples: "//bigquery.googleapis.com/projects
          /projectId/datasets/datasetId/tables/tableId".
          "//pubsub.googleapis.com/projects/projectId/topics/topicId"
      sql_resource:
          The SQL name of the entry. SQL names are case-sensitive.
          Examples:  .. raw:: html     <ul>  .. raw:: html     <li>
          cloud\_pubsub.project\_id.topic\_id  .. raw:: html     </li>
          .. raw:: html     <li>  pubsub.project\_id.\
          ``topic.id.with.dots``  .. raw:: html     </li>  .. raw:: html
          <li>  bigquery.project\_id.dataset\_id.table\_id  .. raw::
          html     </li>  .. raw:: html     <li>  datacatalog.project\_i
          d.location\_id.entry\_group\_id.entry\_id  .. raw:: html
          </li>  .. raw:: html     </ul>  \*\_ids shoud satisfy the
          standard SQL rules for identifiers.
          https://cloud.google.com/bigquery/docs/reference/standard-
          sql/lexical
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.LookupEntryRequest)
    ),
)
_sym_db.RegisterMessage(LookupEntryRequest)

Entry = _reflection.GeneratedProtocolMessageType(
    "Entry",
    (_message.Message,),
    dict(
        DESCRIPTOR=_ENTRY,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Entry Metadata. A Data Catalog Entry resource represents another
  resource in Google Cloud Platform, such as a BigQuery Dataset or a
  Pub/Sub Topic. Clients can use the ``linked_resource`` field in the
  Entry resource to refer to the original resource id of the source
  system.
  
  An Entry resource contains resource details, such as its schema. An
  Entry can also be used to attach flexible metadata, such as a
  [Tag][google.cloud.datacatalog.v1beta1.Tag].
  
  
  Attributes:
      name:
          Required when used in [UpdateEntryRequest][google.cloud.dataca
          talog.v1beta1.UpdateEntryRequest]. The Data Catalog resource
          name of the entry in URL format. For example, "projects/{proje
          ct\_id}/locations/{location}/entryGroups/{entry\_group\_id}/en
          tries/{entry\_id}". Note that this Entry and its child
          resources may not actually be stored in the location in this
          name.
      linked_resource:
          Output only. The full name of the cloud resource the entry
          belongs to. See: https://cloud.google.com/apis/design/resource
          \_names#full\_resource\_name  Data Catalog supports resources
          from select Google Cloud Platform systems. ``linked_resource``
          is the full name of the Google Cloud Platform resource. For
          example, the ``linked_resource`` for a table resource from
          BigQuery is:  "//bigquery.googleapis.com/projects/projectId/da
          tasets/datasetId/tables/tableId".
      type:
          Required. Type of entry.
      type_spec:
          Optional. Type specification information.
      bigquery_table_spec:
          Specification that applies to a BigQuery table. This is only
          valid on entries of type TABLE.
      bigquery_date_sharded_spec:
          Specification for a group of BigQuery tables with name pattern
          [prefix]YYYYMMDD. Context:
          https://cloud.google.com/bigquery/docs/partitioned-
          tables#partitioning\_versus\_sharding
      display_name:
          Optional. Display information such as title and description. A
          short name to identify the entry, for example, "Analytics Data
          - Jan 2011". Default value is an empty string.
      description:
          Optional. Entry description, which can consist of several
          sentences or paragraphs that describe entry contents. Default
          value is an empty string.
      schema:
          Optional. Schema of the entry. An entry might not have any
          schema attached to it.
      source_system_timestamps:
          Output only. Timestamps about the underlying Google Cloud
          Platform resource -- not about this Data Catalog Entry.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.Entry)
    ),
)
_sym_db.RegisterMessage(Entry)

CreateTagTemplateRequest = _reflection.GeneratedProtocolMessageType(
    "CreateTagTemplateRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATETAGTEMPLATEREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [CreateTagTemplate][google.cloud.datacatalog.v1beta1.DataCatalog.CreateTagTemplate].
  
  
  Attributes:
      parent:
          Required. The name of the project and the location this
          template is in. Example:
          "projects/{project\_id}/locations/{location}". Note that this
          TagTemplate and its child resources may not actually be stored
          in the location in this name.
      tag_template_id:
          Required. The id of the tag template to create.
      tag_template:
          Required. The tag template to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.CreateTagTemplateRequest)
    ),
)
_sym_db.RegisterMessage(CreateTagTemplateRequest)

GetTagTemplateRequest = _reflection.GeneratedProtocolMessageType(
    "GetTagTemplateRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETTAGTEMPLATEREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [GetTagTemplate][google.cloud.datacatalog.v1beta1.DataCatalog.GetTagTemplate].
  
  
  Attributes:
      name:
          Required. The name of the tag template. For example, "projects
          /{project\_id}/locations/{location}/tagTemplates/{tag\_templat
          e\_id}".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.GetTagTemplateRequest)
    ),
)
_sym_db.RegisterMessage(GetTagTemplateRequest)

UpdateTagTemplateRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateTagTemplateRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATETAGTEMPLATEREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [UpdateTagTemplate][google.cloud.datacatalog.v1beta1.DataCatalog.UpdateTagTemplate].
  
  
  Attributes:
      tag_template:
          Required. The template to update.
      update_mask:
          Optional. The field mask specifies the parts of the template
          to overwrite.  Allowed fields:  -  display\_name  If
          update\_mask is omitted, all of the allowed fields above will
          be updated.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.UpdateTagTemplateRequest)
    ),
)
_sym_db.RegisterMessage(UpdateTagTemplateRequest)

DeleteTagTemplateRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteTagTemplateRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETETAGTEMPLATEREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [DeleteTagTemplate][google.cloud.datacatalog.v1beta1.DataCatalog.DeleteTagTemplate].
  
  
  Attributes:
      name:
          Required. The name of the tag template to delete. For example,
          "projects/{project\_id}/locations/{location}/tagTemplates/{tag
          \_template\_id}".
      force:
          Required. Currently, this field must always be set to true.
          This confirms the deletion of any possible tags using this
          template. force = false will be supported in the future.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.DeleteTagTemplateRequest)
    ),
)
_sym_db.RegisterMessage(DeleteTagTemplateRequest)

CreateTagRequest = _reflection.GeneratedProtocolMessageType(
    "CreateTagRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATETAGREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [CreateTag][google.cloud.datacatalog.v1beta1.DataCatalog.CreateTag].
  
  
  Attributes:
      parent:
          Required. The name of the resource to attach this tag to. Tags
          can be attached to Entries. (example: "projects/{project\_id}/
          locations/{location}/entryGroups/{entry\_group\_id}/entries/{e
          ntry\_id}"). Note that this Tag and its child resources may
          not actually be stored in the location in this name.
      tag:
          Required. The tag to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.CreateTagRequest)
    ),
)
_sym_db.RegisterMessage(CreateTagRequest)

UpdateTagRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateTagRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATETAGREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [UpdateTag][google.cloud.datacatalog.v1beta1.DataCatalog.UpdateTag].
  
  
  Attributes:
      tag:
          Required. The updated tag.
      update_mask:
          Optional. The fields to update on the Tag. If absent or empty,
          all modifiable fields are updated. Currently the only
          modifiable field is the field ``fields``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.UpdateTagRequest)
    ),
)
_sym_db.RegisterMessage(UpdateTagRequest)

DeleteTagRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteTagRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETETAGREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [DeleteTag][google.cloud.datacatalog.v1beta1.DataCatalog.DeleteTag].
  
  
  Attributes:
      name:
          Required. The name of the tag to delete. For example, "project
          s/{project\_id}/locations/{location}/entryGroups/{entry\_group
          \_id}/entries/{entry\_id}/tags/{tag\_id}".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.DeleteTagRequest)
    ),
)
_sym_db.RegisterMessage(DeleteTagRequest)

CreateTagTemplateFieldRequest = _reflection.GeneratedProtocolMessageType(
    "CreateTagTemplateFieldRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATETAGTEMPLATEFIELDREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [CreateTagTemplateField][google.cloud.datacatalog.v1beta1.DataCatalog.CreateTagTemplateField].
  
  
  Attributes:
      parent:
          Required. The name of the project this template is in.
          Example: "projects/{project\_id}/locations/{location}/tagTempl
          ates/{tag\_template\_id}". Note that this TagTemplateField may
          not actually be stored in the location in this name.
      tag_template_field_id:
          Required. The id of the tag template field to create. Field
          ids can contain letters (both uppercase and lowercase),
          numbers (0-9), underscores (\_) and dashes (-). Field ids must
          be at least 1 character long and at most 128 characters long.
          Field ids must also be unique to their template.
      tag_template_field:
          Required. The tag template field to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.CreateTagTemplateFieldRequest)
    ),
)
_sym_db.RegisterMessage(CreateTagTemplateFieldRequest)

UpdateTagTemplateFieldRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateTagTemplateFieldRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATETAGTEMPLATEFIELDREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [UpdateTagTemplateField][google.cloud.datacatalog.v1beta1.DataCatalog.UpdateTagTemplateField].
  
  
  Attributes:
      name:
          Required. The name of the tag template field. For example, "pr
          ojects/{project\_id}/locations/{location}/tagTemplates/{tag\_t
          emplate\_id}/fields/{tag\_template\_field\_id}".
      tag_template_field:
          Required. The template to update.
      update_mask:
          Optional. The field mask specifies the parts of the template
          to overwrite. Allowed fields:  -  display\_name -
          type.enum\_type  If update\_mask is omitted, all of the
          allowed fields above will be updated.  When updating an enum
          type, the provided values will be merged with the existing
          values. Therefore, enum values can only be added, existing
          enum values cannot be deleted nor renamed.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.UpdateTagTemplateFieldRequest)
    ),
)
_sym_db.RegisterMessage(UpdateTagTemplateFieldRequest)

RenameTagTemplateFieldRequest = _reflection.GeneratedProtocolMessageType(
    "RenameTagTemplateFieldRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_RENAMETAGTEMPLATEFIELDREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [RenameTagTemplateField][google.cloud.datacatalog.v1beta1.DataCatalog.RenameTagTemplateField].
  
  
  Attributes:
      name:
          Required. The name of the tag template. For example, "projects
          /{project\_id}/locations/{location}/tagTemplates/{tag\_templat
          e\_id}/fields/{tag\_template\_field\_id}".
      new_tag_template_field_id:
          Required. The new ID of this tag template field. For example,
          "my\_new\_field".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.RenameTagTemplateFieldRequest)
    ),
)
_sym_db.RegisterMessage(RenameTagTemplateFieldRequest)

DeleteTagTemplateFieldRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteTagTemplateFieldRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETETAGTEMPLATEFIELDREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [DeleteTagTemplateField][google.cloud.datacatalog.v1beta1.DataCatalog.DeleteTagTemplateField].
  
  
  Attributes:
      name:
          Required. The name of the tag template field to delete. For
          example, "projects/{project\_id}/locations/{location}/tagTempl
          ates/{tag\_template\_id}/fields/{tag\_template\_field\_id}".
      force:
          Required. Currently, this field must always be set to true.
          This confirms the deletion of this field from any tags using
          this field. force = false will be supported in the future.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.DeleteTagTemplateFieldRequest)
    ),
)
_sym_db.RegisterMessage(DeleteTagTemplateFieldRequest)

ListTagsRequest = _reflection.GeneratedProtocolMessageType(
    "ListTagsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTTAGSREQUEST,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Request message for
  [ListTags][google.cloud.datacatalog.v1beta1.DataCatalog.ListTags].
  
  
  Attributes:
      parent:
          Required. The name of the Data Catalog resource to list the
          tags of. The resource could be an
          [Entry][google.cloud.datacatalog.v1beta1.Entry].
      page_size:
          Optional. The maximum number of tags to return. Default is 10.
          Max limit is 1000.
      page_token:
          Optional. Token that specifies which page is requested. If
          empty, the first page is returned.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListTagsRequest)
    ),
)
_sym_db.RegisterMessage(ListTagsRequest)

ListTagsResponse = _reflection.GeneratedProtocolMessageType(
    "ListTagsResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTTAGSRESPONSE,
        __module__="google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        __doc__="""Response message for
  [ListTags][google.cloud.datacatalog.v1beta1.DataCatalog.ListTags].
  
  
  Attributes:
      tags:
          [Tag][google.cloud.datacatalog.v1beta1.Tag] details.
      next_page_token:
          Token to retrieve the next page of results. It is set to empty
          if no items remain in results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListTagsResponse)
    ),
)
_sym_db.RegisterMessage(ListTagsResponse)


DESCRIPTOR._options = None

_DATACATALOG = _descriptor.ServiceDescriptor(
    name="DataCatalog",
    full_name="google.cloud.datacatalog.v1beta1.DataCatalog",
    file=DESCRIPTOR,
    index=0,
    serialized_options=_b(
        "\312A\032datacatalog.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform"
    ),
    serialized_start=3025,
    serialized_end=6729,
    methods=[
        _descriptor.MethodDescriptor(
            name="SearchCatalog",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.SearchCatalog",
            index=0,
            containing_service=None,
            input_type=_SEARCHCATALOGREQUEST,
            output_type=_SEARCHCATALOGRESPONSE,
            serialized_options=_b(
                '\202\323\344\223\002\034"\027/v1beta1/catalog:search:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateEntry",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.UpdateEntry",
            index=1,
            containing_service=None,
            input_type=_UPDATEENTRYREQUEST,
            output_type=_ENTRY,
            serialized_options=_b(
                "\202\323\344\223\002M2D/v1beta1/{entry.name=projects/*/locations/*/entryGroups/*/entries/*}:\005entry"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetEntry",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.GetEntry",
            index=2,
            containing_service=None,
            input_type=_GETENTRYREQUEST,
            output_type=_ENTRY,
            serialized_options=_b(
                "\202\323\344\223\002@\022>/v1beta1/{name=projects/*/locations/*/entryGroups/*/entries/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="LookupEntry",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.LookupEntry",
            index=3,
            containing_service=None,
            input_type=_LOOKUPENTRYREQUEST,
            output_type=_ENTRY,
            serialized_options=_b(
                "\202\323\344\223\002\031\022\027/v1beta1/entries:lookup"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="CreateTagTemplate",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.CreateTagTemplate",
            index=4,
            containing_service=None,
            input_type=_CREATETAGTEMPLATEREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATE,
            serialized_options=_b(
                '\202\323\344\223\002E"5/v1beta1/{parent=projects/*/locations/*}/tagTemplates:\014tag_template'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetTagTemplate",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.GetTagTemplate",
            index=5,
            containing_service=None,
            input_type=_GETTAGTEMPLATEREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATE,
            serialized_options=_b(
                "\202\323\344\223\0027\0225/v1beta1/{name=projects/*/locations/*/tagTemplates/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateTagTemplate",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.UpdateTagTemplate",
            index=6,
            containing_service=None,
            input_type=_UPDATETAGTEMPLATEREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATE,
            serialized_options=_b(
                "\202\323\344\223\002R2B/v1beta1/{tag_template.name=projects/*/locations/*/tagTemplates/*}:\014tag_template"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeleteTagTemplate",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.DeleteTagTemplate",
            index=7,
            containing_service=None,
            input_type=_DELETETAGTEMPLATEREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=_b(
                "\202\323\344\223\0027*5/v1beta1/{name=projects/*/locations/*/tagTemplates/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="CreateTagTemplateField",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.CreateTagTemplateField",
            index=8,
            containing_service=None,
            input_type=_CREATETAGTEMPLATEFIELDREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATEFIELD,
            serialized_options=_b(
                '\202\323\344\223\002T">/v1beta1/{parent=projects/*/locations/*/tagTemplates/*}/fields:\022tag_template_field'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateTagTemplateField",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.UpdateTagTemplateField",
            index=9,
            containing_service=None,
            input_type=_UPDATETAGTEMPLATEFIELDREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATEFIELD,
            serialized_options=_b(
                "\202\323\344\223\002T2>/v1beta1/{name=projects/*/locations/*/tagTemplates/*/fields/*}:\022tag_template_field"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="RenameTagTemplateField",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.RenameTagTemplateField",
            index=10,
            containing_service=None,
            input_type=_RENAMETAGTEMPLATEFIELDREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATEFIELD,
            serialized_options=_b(
                '\202\323\344\223\002J"E/v1beta1/{name=projects/*/locations/*/tagTemplates/*/fields/*}:rename:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeleteTagTemplateField",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.DeleteTagTemplateField",
            index=11,
            containing_service=None,
            input_type=_DELETETAGTEMPLATEFIELDREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=_b(
                "\202\323\344\223\002@*>/v1beta1/{name=projects/*/locations/*/tagTemplates/*/fields/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="CreateTag",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.CreateTag",
            index=12,
            containing_service=None,
            input_type=_CREATETAGREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAG,
            serialized_options=_b(
                '\202\323\344\223\002L"E/v1beta1/{parent=projects/*/locations/*/entryGroups/*/entries/*}/tags:\003tag'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateTag",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.UpdateTag",
            index=13,
            containing_service=None,
            input_type=_UPDATETAGREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAG,
            serialized_options=_b(
                "\202\323\344\223\002P2I/v1beta1/{tag.name=projects/*/locations/*/entryGroups/*/entries/*/tags/*}:\003tag"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeleteTag",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.DeleteTag",
            index=14,
            containing_service=None,
            input_type=_DELETETAGREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=_b(
                "\202\323\344\223\002G*E/v1beta1/{name=projects/*/locations/*/entryGroups/*/entries/*/tags/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ListTags",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.ListTags",
            index=15,
            containing_service=None,
            input_type=_LISTTAGSREQUEST,
            output_type=_LISTTAGSRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\002G\022E/v1beta1/{parent=projects/*/locations/*/entryGroups/*/entries/*}/tags"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="SetIamPolicy",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.SetIamPolicy",
            index=16,
            containing_service=None,
            input_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._SETIAMPOLICYREQUEST,
            output_type=google_dot_iam_dot_v1_dot_policy__pb2._POLICY,
            serialized_options=_b(
                '\202\323\344\223\002K"F/v1beta1/{resource=projects/*/locations/*/tagTemplates/*}:setIamPolicy:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetIamPolicy",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.GetIamPolicy",
            index=17,
            containing_service=None,
            input_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._GETIAMPOLICYREQUEST,
            output_type=google_dot_iam_dot_v1_dot_policy__pb2._POLICY,
            serialized_options=_b(
                '\202\323\344\223\002K"F/v1beta1/{resource=projects/*/locations/*/tagTemplates/*}:getIamPolicy:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="TestIamPermissions",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.TestIamPermissions",
            index=18,
            containing_service=None,
            input_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._TESTIAMPERMISSIONSREQUEST,
            output_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._TESTIAMPERMISSIONSRESPONSE,
            serialized_options=_b(
                '\202\323\344\223\002Q"L/v1beta1/{resource=projects/*/locations/*/tagTemplates/*}:testIamPermissions:\001*'
            ),
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_DATACATALOG)

DESCRIPTOR.services_by_name["DataCatalog"] = _DATACATALOG

# @@protoc_insertion_point(module_scope)



config = {
    "interfaces": {
        "google.cloud.datacatalog.v1beta1.DataCatalog": {
            "retry_codes": {
                "idempotent": ["DEADLINE_EXCEEDED", "UNAVAILABLE"],
                "non_idempotent": [],
            },
            "retry_params": {
                "default": {
                    "initial_retry_delay_millis": 100,
                    "retry_delay_multiplier": 1.3,
                    "max_retry_delay_millis": 60000,
                    "initial_rpc_timeout_millis": 20000,
                    "rpc_timeout_multiplier": 1.0,
                    "max_rpc_timeout_millis": 20000,
                    "total_timeout_millis": 600000,
                }
            },
            "methods": {
                "SearchCatalog": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "UpdateEntry": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "GetEntry": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "LookupEntry": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "CreateTagTemplate": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "GetTagTemplate": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "UpdateTagTemplate": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "DeleteTagTemplate": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "CreateTagTemplateField": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "UpdateTagTemplateField": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "RenameTagTemplateField": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "DeleteTagTemplateField": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "CreateTag": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "UpdateTag": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "DeleteTag": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "ListTags": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "idempotent",
                    "retry_params_name": "default",
                },
                "SetIamPolicy": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "GetIamPolicy": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
                "TestIamPermissions": {
                    "timeout_millis": 60000,
                    "retry_codes_name": "non_idempotent",
                    "retry_params_name": "default",
                },
            },
        }
    }
}



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.datacatalog_v1beta1.proto import (
    datacatalog_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2,
)
from google.cloud.datacatalog_v1beta1.proto import (
    tags_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2,
)
from google.iam.v1 import iam_policy_pb2 as google_dot_iam_dot_v1_dot_iam__policy__pb2
from google.iam.v1 import policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class DataCatalogStub(object):
    """Data Catalog API service allows clients to discover, understand, and manage
  their data.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.SearchCatalog = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/SearchCatalog",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.SearchCatalogRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.SearchCatalogResponse.FromString,
        )
        self.UpdateEntry = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/UpdateEntry",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateEntryRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.Entry.FromString,
        )
        self.GetEntry = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/GetEntry",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.GetEntryRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.Entry.FromString,
        )
        self.LookupEntry = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/LookupEntry",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.LookupEntryRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.Entry.FromString,
        )
        self.CreateTagTemplate = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/CreateTagTemplate",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateTagTemplateRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplate.FromString,
        )
        self.GetTagTemplate = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/GetTagTemplate",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.GetTagTemplateRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplate.FromString,
        )
        self.UpdateTagTemplate = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/UpdateTagTemplate",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateTagTemplateRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplate.FromString,
        )
        self.DeleteTagTemplate = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/DeleteTagTemplate",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteTagTemplateRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.CreateTagTemplateField = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/CreateTagTemplateField",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateTagTemplateFieldRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplateField.FromString,
        )
        self.UpdateTagTemplateField = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/UpdateTagTemplateField",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateTagTemplateFieldRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplateField.FromString,
        )
        self.RenameTagTemplateField = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/RenameTagTemplateField",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.RenameTagTemplateFieldRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplateField.FromString,
        )
        self.DeleteTagTemplateField = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/DeleteTagTemplateField",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteTagTemplateFieldRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.CreateTag = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/CreateTag",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateTagRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.Tag.FromString,
        )
        self.UpdateTag = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/UpdateTag",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateTagRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.Tag.FromString,
        )
        self.DeleteTag = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/DeleteTag",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteTagRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.ListTags = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/ListTags",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListTagsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListTagsResponse.FromString,
        )
        self.SetIamPolicy = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/SetIamPolicy",
            request_serializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.SetIamPolicyRequest.SerializeToString,
            response_deserializer=google_dot_iam_dot_v1_dot_policy__pb2.Policy.FromString,
        )
        self.GetIamPolicy = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/GetIamPolicy",
            request_serializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.GetIamPolicyRequest.SerializeToString,
            response_deserializer=google_dot_iam_dot_v1_dot_policy__pb2.Policy.FromString,
        )
        self.TestIamPermissions = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/TestIamPermissions",
            request_serializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.TestIamPermissionsRequest.SerializeToString,
            response_deserializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.TestIamPermissionsResponse.FromString,
        )


class DataCatalogServicer(object):
    """Data Catalog API service allows clients to discover, understand, and manage
  their data.
  """

    def SearchCatalog(self, request, context):
        """Searches Data Catalog for multiple resources like entries, tags that
    match a query.

    This is a custom method
    (https://cloud.google.com/apis/design/custom_methods) and does not return
    the complete resource, only the resource identifier and high level
    fields. Clients can subsequentally call Get methods.

    Note that searches do not have full recall. There may be results that match
    your query but are not returned, even in subsequent pages of results. These
    missing results may vary across repeated calls to search. Do not rely on
    this method if you need to guarantee full recall.

    See [Data Catalog Search
    Syntax](/data-catalog/docs/how-to/search-reference) for more information.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateEntry(self, request, context):
        """Updates an existing entry.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetEntry(self, request, context):
        """Gets an entry.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LookupEntry(self, request, context):
        """Get an entry by target resource name. This method allows clients to use
    the resource name from the source Google Cloud Platform service to get the
    Data Catalog Entry.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateTagTemplate(self, request, context):
        """Creates a tag template.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetTagTemplate(self, request, context):
        """Gets a tag template.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateTagTemplate(self, request, context):
        """Updates a tag template. This method cannot be used to update the fields of
    a template. The tag template fields are represented as separate resources
    and should be updated using their own create/update/delete methods.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteTagTemplate(self, request, context):
        """Deletes a tag template and all tags using the template.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateTagTemplateField(self, request, context):
        """Creates a field in a tag template.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateTagTemplateField(self, request, context):
        """Updates a field in a tag template. This method cannot be used to update the
    field type.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RenameTagTemplateField(self, request, context):
        """Renames a field in a tag template.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteTagTemplateField(self, request, context):
        """Deletes a field in a tag template and all uses of that field.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateTag(self, request, context):
        """Creates a tag on an [Entry][google.cloud.datacatalog.v1beta1.Entry].
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateTag(self, request, context):
        """Updates an existing tag.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteTag(self, request, context):
        """Deletes a tag.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListTags(self, request, context):
        """Lists the tags on an [Entry][google.cloud.datacatalog.v1beta1.Entry].
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SetIamPolicy(self, request, context):
        """Sets the access control policy for a resource. Replaces any existing
    policy.
    Supported resources are:
    - Tag templates.
    Note, this method cannot be used to manage policies for BigQuery, Cloud
    Pub/Sub and any external Google Cloud Platform resources synced to Cloud
    Data Catalog.

    Callers must have following Google IAM permission
    `datacatalog.tagTemplates.setIamPolicy` to set policies on tag templates.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetIamPolicy(self, request, context):
        """Gets the access control policy for a resource. A `NOT_FOUND` error
    is returned if the resource does not exist. An empty policy is returned
    if the resource exists but does not have a policy set on it.

    Supported resources are:
    - Tag templates.
    Note, this method cannot be used to manage policies for BigQuery, Cloud
    Pub/Sub and any external Google Cloud Platform resources synced to Cloud
    Data Catalog.

    Callers must have following Google IAM permission
    `datacatalog.tagTemplates.getIamPolicy` to get policies on tag templates.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TestIamPermissions(self, request, context):
        """Returns the caller's permissions on a resource.
    If the resource does not exist, an empty set of permissions is returned
    (We don't return a `NOT_FOUND` error).

    Supported resource are:
    - tag templates.
    Note, this method cannot be used to manage policies for BigQuery, Cloud
    Pub/Sub and any external Google Cloud Platform resources synced to Cloud
    Data Catalog.

    A caller is not required to have Google IAM permission to make this
    request.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DataCatalogServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "SearchCatalog": grpc.unary_unary_rpc_method_handler(
            servicer.SearchCatalog,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.SearchCatalogRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.SearchCatalogResponse.SerializeToString,
        ),
        "UpdateEntry": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateEntry,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateEntryRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.Entry.SerializeToString,
        ),
        "GetEntry": grpc.unary_unary_rpc_method_handler(
            servicer.GetEntry,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.GetEntryRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.Entry.SerializeToString,
        ),
        "LookupEntry": grpc.unary_unary_rpc_method_handler(
            servicer.LookupEntry,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.LookupEntryRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.Entry.SerializeToString,
        ),
        "CreateTagTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.CreateTagTemplate,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateTagTemplateRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplate.SerializeToString,
        ),
        "GetTagTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.GetTagTemplate,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.GetTagTemplateRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplate.SerializeToString,
        ),
        "UpdateTagTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateTagTemplate,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateTagTemplateRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplate.SerializeToString,
        ),
        "DeleteTagTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteTagTemplate,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteTagTemplateRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "CreateTagTemplateField": grpc.unary_unary_rpc_method_handler(
            servicer.CreateTagTemplateField,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateTagTemplateFieldRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplateField.SerializeToString,
        ),
        "UpdateTagTemplateField": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateTagTemplateField,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateTagTemplateFieldRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplateField.SerializeToString,
        ),
        "RenameTagTemplateField": grpc.unary_unary_rpc_method_handler(
            servicer.RenameTagTemplateField,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.RenameTagTemplateFieldRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplateField.SerializeToString,
        ),
        "DeleteTagTemplateField": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteTagTemplateField,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteTagTemplateFieldRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "CreateTag": grpc.unary_unary_rpc_method_handler(
            servicer.CreateTag,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateTagRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.Tag.SerializeToString,
        ),
        "UpdateTag": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateTag,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateTagRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.Tag.SerializeToString,
        ),
        "DeleteTag": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteTag,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteTagRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "ListTags": grpc.unary_unary_rpc_method_handler(
            servicer.ListTags,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListTagsRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListTagsResponse.SerializeToString,
        ),
        "SetIamPolicy": grpc.unary_unary_rpc_method_handler(
            servicer.SetIamPolicy,
            request_deserializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.SetIamPolicyRequest.FromString,
            response_serializer=google_dot_iam_dot_v1_dot_policy__pb2.Policy.SerializeToString,
        ),
        "GetIamPolicy": grpc.unary_unary_rpc_method_handler(
            servicer.GetIamPolicy,
            request_deserializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.GetIamPolicyRequest.FromString,
            response_serializer=google_dot_iam_dot_v1_dot_policy__pb2.Policy.SerializeToString,
        ),
        "TestIamPermissions": grpc.unary_unary_rpc_method_handler(
            servicer.TestIamPermissions,
            request_deserializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.TestIamPermissionsRequest.FromString,
            response_serializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.TestIamPermissionsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.datacatalog.v1beta1.DataCatalog", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
